Learn R Programming

zoo (version 1.9-1)

lattice-deprecated: Deprecated Time Series Panel Methods for Lattice

Description

Deprecated panel methods for time series objects (of class "zoo", "ts", "its", or "tis").

Usage

panel.plot.default(x, y, subscripts, groups, panel = panel.xyplot,
  col = 1, type = "p", pch = 20, lty = 1, lwd = 1, ...)

panel.plot.custom(...)

panel.lines.zoo(x, ...) panel.lines.ts(x, ...) panel.lines.its(x, ...) panel.lines.tis(x, ...)

panel.points.zoo(x, ...) panel.points.ts(x, ...) panel.points.its(x, ...) panel.points.tis(x, ...)

panel.text.zoo(x, ...) panel.text.ts(x, ...) panel.text.its(x, ...) panel.text.tis(x, ...)

panel.segments.ts(x0, x1, ...) panel.segments.its(x0, x1, ...) panel.segments.tis(x0, x1, ...)

panel.rect.ts(x0, x1, ...) panel.rect.its(x0, x1, ...) panel.rect.tis(x0, x1, ...)

panel.polygon.ts(x, ...) panel.polygon.its(x, ...) panel.polygon.tis(x, ...)

Arguments

x, x0, x1

time series object of class "zoo", "ts", "its" or "tis". For panel.plot.default it should be a numeric vector.

y

numeric vector or matrix.

subscripts, groups, panel, col, type, pch, lty, lwd

lattice graphical arguments.

...

arguments passed on to and from methods.

Details

Since zoo 1.6-3 plot.panel.default and plot.panel.custom are no longer necessary, as normal panel functions (panel.xyplot by default) will work.

Similarly, there are now methods for the generic lattice drawing functions llines, lpoints, and ltext. These can also be called as panel.lines, panel.points, and panel.text, respectively. The old interfaces (panel.lines.zoo, panel.points.zoo, and panel.text.zoo), will be removed in future versions. panel.polygon.zoo may also be removed.

See Also

xyplot.zoo