Learn R Programming

zoo (version 1.9-1)

zoo-methods: Fully Exported zoo Methods

Description

Various standard methods for zoo time series that are fully exported and documented for historical reasons.

Usage

is.zoo(object)

# S3 method for zoo median(x, na.rm = FALSE, ...) # S3 method for zoo quantile(x, ...) # S3 method for zoo ifelse(test, yes, no) # S3 method for zoo rev(x) # S3 method for zoo xtfrm(x)

Arguments

object, x, test

a zoo object.

na.rm

a logical value indicating whether NA values should be stripped before the computation proceeds.

yes, no

return values for true and false elements of test, respectively.

...

further arguments passed to methods.

See Also

zoo